// 


const RouterSchema = require('./router_schema');
const utils = require('./utils');

/**
 * ExpressRouterSchema
 *
 * @class ExpressRouterSchema
 * @extends {RouterSchema}
 */
class ExpressRouterSchema extends RouterSchema {
  constructor(option) {
    super(option);
  }
  /**
   * Implement RouterSchema.handler()
   *
   * @override
   * @param {$Request} req
   * @param {$Response} res
   * @param {NextFunction} next
   * @returns {ValidateData}
   * @memberof ExpressRouterSchema
   */
  handler(req, res, next) {
    const hasQuery = !utils.isEmptyObject(req.query);
    const hasBody = !utils.isEmptyObject(req.body);

    const data = {};
    if (hasQuery) data.query = req.query;
    if (hasBody) data.body = req.body;

    const callback = (error, value) => {
      if (error) {
        return next(error);
      }
      if (value) {
        if (hasQuery) req.query = value.query;
        if (hasBody) req.body = value.body;
      }

      return next();
    };
    return { data, callback };
  }
}

module.exports = ExpressRouterSchema;
